#
# spec file for package haxe
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global commit_ocamllibs 7a83e902634e1db204f6e3a48c2439f63d83c141
%global commit_haxelib 4fefbd17a2d9a98200b621de801018af3896d68a

Name:           haxe
Version:        3.2.1
Release:        5.1
Summary:        Multiplatform opensource programming language
License:        GPL-2.0+ and MIT
Group:          Development/Languages/Other
# As described in http://haxe.org/foundation/open-source.html:
#   * The Haxe Compiler - GPLv2+
#   * The Haxe Standard Library - MIT
Url:            http://www.haxe.org
Source0:        https://github.com/HaxeFoundation/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/HaxeFoundation/ocamllibs/archive/%{commit_ocamllibs}.tar.gz#/ocamllibs-%{commit_ocamllibs}.tar.gz
Source2:        https://github.com/HaxeFoundation/haxelib/archive/%{commit_haxelib}.tar.gz#/haxelib-%{commit_haxelib}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  help2man
BuildRequires:  nekovm >= 2.0.0
BuildRequires:  ocaml-camlp4-devel
BuildRequires:  pkgconfig(zlib)
Requires:       nekovm >= 2.0.0

%description
Haxe is an open-source high-level multiplatform programming language and compiler that can produce applications and source code for many different platforms from a single code-base. The Haxe compiler can compile Haxe source code to Adobe Flash SWF files, ActionScript 3, JavaScript, C++, PHP, C#, Java, Python, and Neko VM binary files.

%prep
%setup -q
pushd libs && tar -xf %{SOURCE1} --strip-components=1 && popd
pushd extra/haxelib_src && tar -xf %{SOURCE2} --strip-components=1 && popd

# script-without-shebang
# https://github.com/HaxeFoundation/haxe/commit/7ecbc2baaef0e2f653f43b01071ffff0050ec5d3
chmod a-x std/js/Boot.hx std/js/_std/Type.hx std/php/_std/haxe/ds/StringMap.hx
chmod a-x libs/extlib/extList.ml

%build
# note that the Makefile does not support parallel building

# Check to see if ocamlopt exists. If not, bytecompile everything.
# It is because ocamlopt may be missing in some architectures.
command -v ocamlopt && make || make BYTECODE=1

# Compile haxelib
make tools

chmod 755 haxe haxelib

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/%{name}

cp -p haxe %{buildroot}%{_bindir}
cp -p haxelib %{buildroot}%{_bindir}
cp -rfp std %{buildroot}%{_datadir}/%{name}

# Generate man pages
mkdir -p %{buildroot}%{_mandir}/man1
help2man ./haxe --version-option=-version --no-discard-stderr --no-info --output=%{buildroot}%{_mandir}/man1/haxe.1
help2man ./haxelib --help-option=help --version-option=version --no-info --output=%{buildroot}%{_mandir}/man1/haxelib.1

%check
%{buildroot}%{_bindir}/haxe -version
pushd tests/unit && %{buildroot}%{_bindir}/haxe compile-macro.hxml && popd

%files
%defattr(-,root,root)
%doc README.md extra/LICENSE.txt extra/CHANGES.txt extra/CONTRIB.txt
%{_bindir}/haxe
%{_bindir}/haxelib
%{_mandir}/man1/haxe.1*
%{_mandir}/man1/haxelib.1*
%{_datadir}/%{name}/

%changelog
* Mon Nov 23 2015 andy@onthewings.net
- Updated to 3.2.1.
- Moved the haxe standard library files to _datadir.
- Generate man pages using help2man.
- Spec file clean-up.
  * Clarified license.
  * Manually cp files instead of using "make install".
  * Added BuildRoot as suggested in openSUSE specfile guidelines.
* Sun Jun  7 2015 pvince81@opensuse.org
- Fix haxelib shell script to properly pass arguments
* Sat May 16 2015 dap.darkness@gmail.com
- Updated to 4.2.0:
  * New features:
    + all: added @:noPrivateAccess to re-enable access
    restrictions within @:privateAccess
    + cpp: some support for @:nativeGen metadata
  * Bugfixes:
    + all: @:generic classes with constructor constraints detection
    + all: variable initialization check issue in loop condition
    + all: pattern matching on @:enum abstracts via field access
    + all: missing implicit casts in Map literals (#4100)
    + all: various minor issues in haxe.xml.Parser
    + all: class path issue when HAXE_STD_PATH is set (#4163)
    + js: DCE issue related to printing enums (#4197)
    + js: various issues with the new Bytes implementation
    + php: EOF handling in FileInput.readByte (#4082)
    + cs/java: Math.fround implementation (#4177)
    + cs/java: some cases of Std.parseInt failing (#4132)
    + cpp: compilation without -main (#4199)
  * General improvements and optimizations:
    + all: --macro keep no longer causes types to be included
    for compilation
    + php: support interpolation in php code
    + js: added variable number of arguments support
    in js.html.* classes
    + js: refined new HTML externs
  * Macro features and changes:
    + macro: [breaking] synced FClosure and FInstance
    with the compiler updates
- %%install section refactoring.
- general spec file clean-up.
* Sun May 10 2015 dap.darkness@gmail.com
- Added missing files to resolve builds issue.
- Fixed various warnings.
* Sat Jan 24 2015 prusnak@opensuse.org
- imported package from dmacvicar
- update to version 3.1.3
